function [p1,p2,service1Level,service2Level,service3Level,cost,reliability,performance] = importfile(filename, startRow, endRow)
%IMPORTFILE Import numeric data from a text file as column vectors.
%   [P1,P2,SERVICE1LEVEL,SERVICE2LEVEL,SERVICE3LEVEL,COST,RELIABILITY,PERFORMANCE]
%   = IMPORTFILE(FILENAME) Reads data from text file FILENAME for the
%   default selection.
%
%   [P1,P2,SERVICE1LEVEL,SERVICE2LEVEL,SERVICE3LEVEL,COST,RELIABILITY,PERFORMANCE]
%   = IMPORTFILE(FILENAME, STARTROW, ENDROW) Reads data from rows STARTROW
%   through ENDROW of text file FILENAME.
%
% Example:
%   [p1,p2,service1Level,service2Level,service3Level,cost,reliability,performance] = importfile('dataSimBinder01-fse15-systematic_ale.csv',2, 5001);
%
%    See also TEXTSCAN.

% Auto-generated by MATLAB on 2016/08/03 15:38:52

%% Initialize variables.
delimiter = ' ';
if nargin<=2
    startRow = 2;
    endRow = inf;
end

%% Format string for each line of text:
%   column1: double (%f)
%	column2: double (%f)
%   column3: double (%f)
%	column4: double (%f)
%   column5: double (%f)
%	column6: double (%f)
%   column7: double (%f)
%	column8: double (%f)
% For more information, see the TEXTSCAN documentation.
formatSpec = '%f%f%f%f%f%f%f%f%[^\n\r]';

%% Open the text file.
fileID = fopen(filename,'r');

%% Read columns of data according to format string.
% This call is based on the structure of the file used to generate this
% code. If an error occurs for a different file, try regenerating the code
% from the Import Tool.
dataArray = textscan(fileID, formatSpec, endRow(1)-startRow(1)+1, 'Delimiter', delimiter, 'MultipleDelimsAsOne', true, 'EmptyValue' ,NaN,'HeaderLines', startRow(1)-1, 'ReturnOnError', false);
for block=2:length(startRow)
    frewind(fileID);
    dataArrayBlock = textscan(fileID, formatSpec, endRow(block)-startRow(block)+1, 'Delimiter', delimiter, 'MultipleDelimsAsOne', true, 'EmptyValue' ,NaN,'HeaderLines', startRow(block)-1, 'ReturnOnError', false);
    for col=1:length(dataArray)
        dataArray{col} = [dataArray{col};dataArrayBlock{col}];
    end
end

%% Close the text file.
fclose(fileID);

%% Post processing for unimportable data.
% No unimportable data rules were applied during the import, so no post
% processing code is included. To generate code which works for
% unimportable data, select unimportable cells in a file and regenerate the
% script.

%% Allocate imported array to column variable names
p1 = dataArray{:, 1};
p2 = dataArray{:, 2};
service1Level = dataArray{:, 3};
service2Level = dataArray{:, 4};
service3Level = dataArray{:, 5};
cost = dataArray{:, 6};
reliability = dataArray{:, 7};
performance = dataArray{:, 8};


